Class: Google::Apis::BusinessprofileperformanceV1::ListSearchKeywordImpressionsMonthlyResponse
- Inherits:
-
Object
- Object
- Google::Apis::BusinessprofileperformanceV1::ListSearchKeywordImpressionsMonthlyResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/businessprofileperformance_v1/classes.rb,
lib/google/apis/businessprofileperformance_v1/representations.rb,
lib/google/apis/businessprofileperformance_v1/representations.rb
Overview
Represents the response for ListSearchKeywordImpressionsMonthly.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token indicating the last paginated result returned.
-
#search_keywords_counts ⇒ Array<Google::Apis::BusinessprofileperformanceV1::SearchKeywordCount>
Search terms which have been used to find a business.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListSearchKeywordImpressionsMonthlyResponse
constructor
A new instance of ListSearchKeywordImpressionsMonthlyResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListSearchKeywordImpressionsMonthlyResponse
Returns a new instance of ListSearchKeywordImpressionsMonthlyResponse.
243 244 245 |
# File 'lib/google/apis/businessprofileperformance_v1/classes.rb', line 243 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token indicating the last paginated result returned. This can be used by
succeeding requests to get the next "page" of keywords. It will only be
present when there are more results to be returned.
Corresponds to the JSON property nextPageToken
NOTE: Values are automatically base64 encoded/decoded in the client library.
236 237 238 |
# File 'lib/google/apis/businessprofileperformance_v1/classes.rb', line 236 def next_page_token @next_page_token end |
#search_keywords_counts ⇒ Array<Google::Apis::BusinessprofileperformanceV1::SearchKeywordCount>
Search terms which have been used to find a business.
Corresponds to the JSON property searchKeywordsCounts
241 242 243 |
# File 'lib/google/apis/businessprofileperformance_v1/classes.rb', line 241 def search_keywords_counts @search_keywords_counts end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
248 249 250 251 |
# File 'lib/google/apis/businessprofileperformance_v1/classes.rb', line 248 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @search_keywords_counts = args[:search_keywords_counts] if args.key?(:search_keywords_counts) end |